# `autopew`

<p align="left">
<a href="https://autopew.readthedocs.io/">
   <img src="https://readthedocs.org/projects/autopew/badge/?version=develop" alt="Docs"/></a>

<a href="https://github.com/morganjwilliams/autopew/blob/master/LICENSE" >
  <img src="https://img.shields.io/badge/License-CSIRO_BSD/MIT_License-blue.svg"
       alt="License: CSIRO Modified BSD/MIT License"></a>
<a href="https://gitter.im/pyrolite/autopew" >
 <img src="https://img.shields.io/gitter/room/pyrolite/autopew.svg"
      alt="Chat on Gitter"></a>
</p>

Automating sample targeting for geological microanalysis systems.

For more information, see the documentation's [installation page](https://autopew.readthedocs.io/en/develop/installation.html), and the [Getting Started Guide](https://autopew.readthedocs.io/en/develop/gettingstarted.html).

## Development & Build Status
<p align='left'>
  <a href="https://github.com/python/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg"
         alt="Code Style: Black"></a>
</p>

| **master** | **develop** |
|:----------:|:-----------:|
| [![Build Status](https://travis-ci.com/morganjwilliams/autopew.svg?branch=master)](https://travis-ci.com/morganjwilliams/autopew) | [![Build Status](https://travis-ci.com/morganjwilliams/autopew.svg?branch=develop)](https://travis-ci.com/morganjwilliams/autopew) |
| [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/autopew/badge.svg?branch=master)](https://coveralls.io/github/morganjwilliams/autopew?branch=master) | [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/autopew/badge.svg?branch=develop)](https://coveralls.io/github/morganjwilliams/autopew?branch=develop) |
